<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ArcTangential</name>
    <message>
        <location filename="../ArcTangential.js" line="+63"/>
        <source>Choose base line or base arc</source>
        <translation>Izberi nosilno črto ali nosilni lok</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Choose end point of arc</source>
        <translation>Izberi končno točko loka</translation>
    </message>
    <message>
        <location filename="../ArcTangential.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Polmer:</translation>
    </message>
    <message>
        <source>&amp;Tangentially connected</source>
        <translation type="vanished">&amp;Tangencialno povezano</translation>
    </message>
    <message>
        <location filename="../ArcTangentialInit.js" line="+2"/>
        <source>&amp;Tangentially Connected</source>
        <translation>&amp;Tangencialno povezano</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to base entity</source>
        <translation>Izriši lok tangencialno na nosilni element</translation>
    </message>
</context>
</TS>
